
# GPT Roles
Simple PyQT chatbox that connects to a chat session with GPT.

Has some features to increase interactivity and context awareness:
    - GPT can request web pages or from APIs to answer your questions, to get current prices or latest news
    - GPT can run shell scripts on your computer, so you can ask it directly to find files or open programs

These are programmed in a root prompt.
Be direct as possible in your commands or questions to get them issued correctly.

TODO: The chat UI has action indicators for the interactivity
TODO: Also the messages in the current prompt chain are

TODO: List and add roles from jailbreakchat.com

## Installing/Running

#### From source with Poetry
```shell
poetry install && poetry run main
```

#### From pip
TODO

